==> openjdk-17_17.0.1+12.orig.tar.xz: openjdk-17-17.0.1+12/src/java.desktop/macosx/native/libawt_lwawt/awt/a11y/StaticTextAccessibility.m <==
/*
 * Copyright (c) 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

#import "StaticTextAccessibility.h"

@implementation StaticTextAccessibility

- (NSAccessibilityRole _Nonnull)accessibilityRole
{
    return NSAccessibilityStaticTextRole;
}

- (NSString * _Nullable)accessibilityAttributedStringForRange:(NSRange)range
{
    return [self accessibilityStringForRangeAttribute:range];
}

- (NSString * _Nullable)accessibilityValue
{
    return [self accessibilityValueAttribute];
}

- (NSRange)accessibilityVisibleCharacterRange
{
    return [self accessibilityVisibleCharacterRangeAttribute];
}

@end

==> openjdk-17_17.0.12+7.orig.tar.xz: openjdk-17-17.0.12+7/src/java.desktop/macosx/native/libawt_lwawt/awt/a11y/StaticTextAccessibility.m <==
/*
 * Copyright (c) 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

#import "StaticTextAccessibility.h"

@implementation StaticTextAccessibility

- (NSAccessibilityRole _Nonnull)accessibilityRole
{
    return NSAccessibilityStaticTextRole;
}

- (NSString * _Nullable)accessibilityAttributedStringForRange:(NSRange)range
{
    return [self accessibilityStringForRangeAttribute:range];
}

- (NSString * _Nullable)accessibilityValue
{
    return [self accessibilityValueAttribute];
}

- (NSRange)accessibilityVisibleCharacterRange
{
    return [self accessibilityVisibleCharacterRangeAttribute];
}

- (NSRect)accessibilityFrame
{
    return [super accessibilityFrame];
}

- (id)accessibilityParent
{
    return [super accessibilityParent];
}

@end
